@@ -1,11 +1,11 @@
 package Sah::Schema::url;
 
-our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-02-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
-our $schema = ['str', {
+our $schema = ['obj', {
     summary => 'URL string',
-    min_len => 1,
+    isa => 'URI',
 }, {}];
 
 1;
@@ -23,7 +23,7 @@ Sah::Schema::url - URL string
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::url (from Perl distribution Sah-Schemas-URL), released on 2016-07-22.
+This document describes version 0.003 of Sah::Schema::url (from Perl distribution Sah-Schemas-URL), released on 2017-02-25.
 
 =head1 HOMEPAGE
 
@@ -47,7 +47,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
